Index: tools/dom/scripts/generator.py |
diff --git a/tools/dom/scripts/generator.py b/tools/dom/scripts/generator.py |
index c5a8649ab4f36de3f495c47d2797aa950843177a..6163f5347266fbb25f98002d7d43ce88a0664e19 100644 |
--- a/tools/dom/scripts/generator.py |
+++ b/tools/dom/scripts/generator.py |
@@ -385,7 +385,7 @@ class OperationInfo(object): |
else: |
# TODO(antonm): temporary ugly hack. |
# While in transition phase we allow both DOM's ArrayBuffer |
# and dart:typeddata's ByteBuffer for IDLs' ArrayBuffers, |
# hence ArrayBuffer is mapped to dynamic in arguments and return |
# values. To compensate for that when generating ArrayBuffer itself, |
# we need to lie a bit: |
@@ -1379,7 +1379,7 @@ class TypeData(object): |
def TypedListTypeData(item_type): |
return TypeData( |
clazz='TypedList', |
- dart_type='List<%s>' % item_type, # TODO(antonm): proper typeddata interfaces. |
+ dart_type='List<%s>' % item_type, # TODO(antonm): proper typed_data interfaces. |
item_type=item_type, |
is_typed_array=True) |
@@ -385,7 +385,7 @@ class OperationInfo(object): |
# TODO(antonm): temporary ugly hack. |
# While in transition phase we allow both DOM's ArrayBuffer |
- # and dart:typeddata's ByteBuffer for IDLs' ArrayBuffers, |
+ # and dart:typed_data's ByteBuffer for IDLs' ArrayBuffers, |
# hence ArrayBuffer is mapped to dynamic in arguments and return |
# values. To compensate for that when generating ArrayBuffer itself, |